"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const restults_1 = require("./restults");
const index_1 = require("./index");
/**
 * Base Controller.
 *
 * @export
 * @class Controller
 */
class BaseController {
    /**
     * respone view result.
     *
     * @param {string} viewName
     * @param {object} [model]
     * @returns
     * @memberof BaseController
     */
    view(viewName, model) {
        return new restults_1.ViewResult(viewName, model);
    }
    /**
     * respone file result.
     *
     * @param {(string | Buffer | Stream)} file
     * @param {string} [contentType]
     * @param {string} [fileDownloadName]
     * @returns
     * @memberof BaseController
     */
    file(file, contentType, fileDownloadName) {
        return new restults_1.FileResult(file, contentType, fileDownloadName);
    }
    /**
     * respone redirect result.
     * Perform a 302 redirect to `url`.
     *
     * The string "back" is special-cased
     * to provide Referrer support, when Referrer
     * is not present `alt` or "/" is used.
     *
     * Examples:
     *
     *    this.redirect('back');
     *    this.redirect('back', '/index.html');
     *    this.redirect('/login');
     *    this.redirect('http://google.com');
     * @param {string} url
     * @param {string} [alt]
     * @returns
     * @memberof BaseController
     */
    redirect(url, alt) {
        return new index_1.RedirectResult(url, alt);
    }
    /**
     * respone json result.
     *
     * @param {object} data
     * @returns
     * @memberof BaseController
     */
    json(data) {
        return new index_1.JsonResult(data);
    }
}
exports.BaseController = BaseController;

//# sourceMappingURL=sourcemaps/BaseController.js.map
